==> v21.04.tar.gz: bookstack/resources/lang/de/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Abbrechen',
    'confirm' => 'Bestätigen',
    'back' => 'Zurück',
    'save' => 'Speichern',
    'continue' => 'Weiter',
    'select' => 'Auswählen',
    'toggle_all' => 'Alle umschalten',
    'more' => 'Mehr',

    // Form Labels
    'name' => 'Name',
    'description' => 'Beschreibung',
    'role' => 'Rolle',
    'cover_image' => 'Titelbild',
    'cover_image_description' => 'Das Bild sollte eine Auflösung von 440x250px haben.',
    
    // Actions
    'actions' => 'Aktionen',
    'view' => 'Anzeigen',
    'view_all' => 'Alle anzeigen',
    'create' => 'Anlegen',
    'update' => 'Aktualisieren',
    'edit' => 'Bearbeiten',
    'sort' => 'Sortieren',
    'move' => 'Verschieben',
    'copy' => 'Kopieren',
    'reply' => 'Antworten',
    'delete' => 'Löschen',
    'delete_confirm' => 'Löschen Bestätigen',
    'search' => 'Suchen',
    'search_clear' => 'Suche löschen',
    'reset' => 'Zurücksetzen',
    'remove' => 'Entfernen',
    'add' => 'Hinzufügen',
    'fullscreen' => 'Vollbild',

    // Sort Options
    'sort_options' => 'Sortieroptionen',
    'sort_direction_toggle' => 'Sortierreihenfolge umkehren',
    'sort_ascending' => 'Aufsteigend sortieren',
    'sort_descending' => 'Absteigend sortieren',
    'sort_name' => 'Name',
    'sort_default' => 'Default',
    'sort_created_at' => 'Erstellungsdatum',
    'sort_updated_at' => 'Aktualisierungsdatum',

    // Misc
    'deleted_user' => 'Gelöschte Benutzer',
    'no_activity' => 'Keine Aktivitäten zum Anzeigen',
    'no_items' => 'Keine Einträge gefunden.',
    'back_to_top' => 'nach oben',
    'toggle_details' => 'Details zeigen/verstecken',
    'toggle_thumbnails' => 'Thumbnails zeigen/verstecken',
    'details' => 'Details',
    'grid_view' => 'Gitteransicht',
    'list_view' => 'Listenansicht',
    'default' => 'Voreinstellung',
    'breadcrumb' => 'Brotkrumen',

    // Header
    'profile_menu' => 'Profilmenü',
    'view_profile' => 'Profil ansehen',
    'edit_profile' => 'Profil bearbeiten',
    'dark_mode' => 'Dunkler Modus',
    'light_mode' => 'Heller Modus',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_content' => 'Inhalt',

    // Email Content
    'email_action_help' => 'Sollte es beim Anklicken der Schaltfläche ":action_text" Probleme geben, öffnen Sie folgende URL in Ihrem Browser:',
    'email_rights' => 'Alle Rechte vorbehalten',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Datenschutzbestimmungen',
    'terms_of_service' => 'Allgemeine Geschäftsbedingungen',
];

==> v21.05.tar.gz: bookstack/resources/lang/de/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Abbrechen',
    'confirm' => 'Bestätigen',
    'back' => 'Zurück',
    'save' => 'Speichern',
    'continue' => 'Weiter',
    'select' => 'Auswählen',
    'toggle_all' => 'Alle umschalten',
    'more' => 'Mehr',

    // Form Labels
    'name' => 'Name',
    'description' => 'Beschreibung',
    'role' => 'Rolle',
    'cover_image' => 'Titelbild',
    'cover_image_description' => 'Das Bild sollte eine Auflösung von 440x250px haben.',
    
    // Actions
    'actions' => 'Aktionen',
    'view' => 'Anzeigen',
    'view_all' => 'Alle anzeigen',
    'create' => 'Anlegen',
    'update' => 'Aktualisieren',
    'edit' => 'Bearbeiten',
    'sort' => 'Sortieren',
    'move' => 'Verschieben',
    'copy' => 'Kopieren',
    'reply' => 'Antworten',
    'delete' => 'Löschen',
    'delete_confirm' => 'Löschen Bestätigen',
    'search' => 'Suchen',
    'search_clear' => 'Suche löschen',
    'reset' => 'Zurücksetzen',
    'remove' => 'Entfernen',
    'add' => 'Hinzufügen',
    'fullscreen' => 'Vollbild',
    'favourite' => 'Favorit',
    'unfavourite' => 'Kein Favorit',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'Sortieroptionen',
    'sort_direction_toggle' => 'Sortierreihenfolge umkehren',
    'sort_ascending' => 'Aufsteigend sortieren',
    'sort_descending' => 'Absteigend sortieren',
    'sort_name' => 'Name',
    'sort_default' => 'Standard',
    'sort_created_at' => 'Erstellungsdatum',
    'sort_updated_at' => 'Aktualisierungsdatum',

    // Misc
    'deleted_user' => 'Gelöschte Benutzer',
    'no_activity' => 'Keine Aktivitäten zum Anzeigen',
    'no_items' => 'Keine Einträge gefunden.',
    'back_to_top' => 'nach oben',
    'toggle_details' => 'Details zeigen/verstecken',
    'toggle_thumbnails' => 'Thumbnails zeigen/verstecken',
    'details' => 'Details',
    'grid_view' => 'Gitteransicht',
    'list_view' => 'Listenansicht',
    'default' => 'Voreinstellung',
    'breadcrumb' => 'Brotkrumen',

    // Header
    'header_menu_expand' => 'Header-Menü erweitern',
    'profile_menu' => 'Profilmenü',
    'view_profile' => 'Profil ansehen',
    'edit_profile' => 'Profil bearbeiten',
    'dark_mode' => 'Dunkler Modus',
    'light_mode' => 'Heller Modus',

    // Layout tabs
    'tab_info' => 'Info',
    'tab_info_label' => 'Tab: Sekundäre Informationen anzeigen',
    'tab_content' => 'Inhalt',
    'tab_content_label' => 'Tab: Hauptinhalt anzeigen',

    // Email Content
    'email_action_help' => 'Sollte es beim Anklicken der Schaltfläche ":action_text" Probleme geben, öffnen Sie folgende URL in Ihrem Browser:',
    'email_rights' => 'Alle Rechte vorbehalten',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Datenschutzbestimmungen',
    'terms_of_service' => 'Allgemeine Geschäftsbedingungen',
];
